

[![codecov](https://codecov.io/gh/earthlab/abc-classroom/branch/master/graph/badge.svg)](https://codecov.io/gh/earthlab/abc-classroom)


# ABC Classroom

> A set of tools to manage your notebooks and assignments for a class.


## Try it!

Run `pip install -e .` in the directory of this README.


## Dev
